@@ -3,7 +3,7 @@ use warnings;
 
 package Net::Amazon::Route53::Change;
 BEGIN {
-  $Net::Amazon::Route53::Change::VERSION = '0.111300';
+  $Net::Amazon::Route53::Change::VERSION = '0.113490';
 }
 use Mouse;
 use HTML::Entities;
@@ -26,7 +26,7 @@ to Amazon's Route 53 service
 
 =cut
 
-has 'route53' => ( is => 'rw', isa => 'Net::Amazon::Route53', required => 1, );
+has 'route53' => (is => 'rw', isa => 'Net::Amazon::Route53', required => 1,);
 
 =head3 id
 
@@ -47,9 +47,9 @@ Any Comment given when the zone is created
 
 =cut
 
-has 'id'          => ( is => 'rw', isa => 'Str', required => 1, default => '' );
-has 'status'      => ( is => 'rw', isa => 'Str', required => 1, default => '' );
-has 'submittedat' => ( is => 'rw', isa => 'Str', required => 1, default => '' );
+has 'id'          => (is => 'rw', isa => 'Str', required => 1, default => '');
+has 'status'      => (is => 'rw', isa => 'Str', required => 1, default => '');
+has 'submittedat' => (is => 'rw', isa => 'Str', required => 1, default => '');
 
 =head2 METHODS
 
@@ -64,13 +64,10 @@ Refresh the details of the change. When performed, the object's status is curren
 sub refresh {
     my $self = shift;
     die "Cannot refresh without an id\n" unless length $self->id;
-    my $resp =
-      $self->route53->request( 'get',
-        'https://route53.amazonaws.com/2010-10-01/' . $self->id,
-      );
+    my $resp = $self->route53->request('get', 'https://route53.amazonaws.com/2010-10-01/' . $self->id,);
     for (qw/Id Status SubmittedAt/) {
         my $method = lc $_;
-        $self->$method( decode_entities( $resp->{ChangeInfo}{$_} ) );
+        $self->$method(decode_entities($resp->{ChangeInfo}{$_}));
     }
 }
 
